==> lxqt-panel-0.14.0.tar.xz: lxqt-panel-0.14.0/plugin-sensors/translations/sensors_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation type="unfinished">Postavke senzora</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation type="unfinished">Uobičajeno</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation type="unfinished">Interval ažuriranja (sekunde)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation type="unfinished">Duljina trake temperature</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation type="unfinished">Skala temperature</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation type="unfinished">Celzijus</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation type="unfinished">Fahrenheit</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation type="unfinished">Upozori na visoku temperaturu</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation type="unfinished">Senzori</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation type="unfinished">Nađeni čipovi:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation type="unfinished">Omogućeno</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation type="unfinished">Boja</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-sensors/translations/sensors_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Senzori – Postavke</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Uobičajene</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Interval aktualiziranja (sekunde)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Duljina trake temperature</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Temperaturna ljestvica</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Celzijeva</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheitova</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation>Traka stanja treperi kad je temperatura previsoka</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Upozori na visoku temperaturu</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Senzori</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Nađeni čipovi:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Funkcije čipova:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Enabled</source>
        <translation>Aktivirano</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Label</source>
        <translation>Oznaka</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="195"/>
        <source>Color</source>
        <translation>Boja</translation>
    </message>
</context>
</TS>
